@@ -17,3 +17,10 @@
 # along with this program; if not, see <http://www.gnu.org/licenses/>
 #
 # --
+"""RepRepBuild package."""
+
+try:
+    from _version import __version__
+except ImportError:
+    __version__ = "0.0.0a-dev"
+    __version_tuple__ = (0, 0, 0, "a-dev")
